@@ -8,14 +8,16 @@ compute_ROC <- function(marker, probs, grid){
   dtu <- unique(dt)
   ROC <- approxfun(c(0, 1-dtu$SP, 1), c(0, dtu$SE, 1), ties = max)(u)
   auc <- sum(ROC) * 1/grid
+  dts <- cbind(dt, probs = probs)
+  dts <- dts[order(dts$SP),]
   ret      <- list()
-  ret$SE   <- SE
-  ret$SP   <- SP
+  ret$SE   <- dts$SE
+  ret$SP   <- dts$SP
   ret$u    <- u
   ret$ROC  <- ROC
   ret$auc  <- auc
-  ret$marker <- marker
-  ret$probs  <- probs
+  ret$marker <- dts$marker
+  ret$probs  <- dts$probs
   ret
 }
 sMS_binout <- function(marker, status, meth, grid, probs, all){
@@ -43,8 +45,8 @@ sMS_binout <- function(marker, status, meth, grid, probs, all){
     ret$u    <- bin.ROC$u
     ret$ROC  <- bin.ROC$ROC
     ret$auc  <- bin.ROC$auc
-    ret$marker <- p.model$marker
-    ret$probs  <- p.model$probs
+    ret$marker <- bin.ROC$marker
+    ret$probs  <- bin.ROC$probs
     ret
 }
 sMS_timerc <- function(marker,
@@ -81,9 +83,9 @@ sMS_timerc <- function(marker,
   ret$u    <- timrc.ROC$u
   ret$ROC  <- timrc.ROC$ROC
   ret$auc  <- timrc.ROC$auc
-  ret$marker  <- p.model$marker
-  ret$outcome <- p.model$outcome
-  ret$probs   <- p.model$probs
+  ret$marker  <- timrc.ROC$marker
+  ret$outcome <- timrc.ROC$outcome
+  ret$probs   <- timrc.ROC$probs
   ret
 }
 sMS_timeic <- function(marker, left, right, outcome, time, meth, grid, probs, all){
@@ -111,8 +113,8 @@ sMS_timeic <- function(marker, left, right, outcome, time, meth, grid, probs, al
   ret$u    <- timeic.ROC$u
   ret$ROC  <- timeic.ROC$ROC
   ret$auc  <- timeic.ROC$auc
-  ret$marker <- p.model$marker
-  ret$oucome <- p.model$outcome
-  ret$probs  <- p.model$probs
+  ret$marker <- timeic.ROC$marker
+  ret$oucome <- timeic.ROC$outcome
+  ret$probs  <- timeic.ROC$probs
   ret
 }
