@@ -57,7 +57,7 @@ probs_pred <- function (sMS,
               aes(x = x, ymin = ymin, ymax = ymax, fill = "#f0f8ff"),
               alpha = 0.8, size =1.2, color = "#f0f8ff", show.legend = FALSE ) +
               scale_fill_manual(values = "#f0f8ff") +
-              geom_line(size = 1.5, colour = "#003366")+
+              geom_line(linewidth = 1.5, colour = "#003366")+
               xlab("Marker") +
               ylab("Probability") +
               ggtitle("Predictive Model") +
@@ -136,14 +136,16 @@ sMSROC_plot <- function(sMS, m.value){
     m <- paste("Object", sMS, "should be 'sMSROC' object")
     stop(m)
   }
-  SP  <- NULL; SP  <- sMS$SP
   TPR <- NULL; TPR <- c(0, sMS$SE, 1)
-  FPR <- NULL; FPR <- c(0, 1-SP, 1)
+  FPR <- NULL; FPR <- c(0, 1-sMS$SP, 1)
   thr <- NULL; thr <- c(sMS$thres[length(sMS$thres)], sMS$thres, sMS$thres[1])
   x   <- NULL; y   <- NULL;  m   <- NULL
   df  <- unique(data.frame(thr = thr, FPR = FPR, TPR = TPR))
   df  <- df[order(df$FPR),]
+  Its <- which(duplicated(df$FPR))
+  if (length(Its) > 0){ df  <- df[-Its,]}
   df1 <- data.frame(x = c(0,1), y = c(0,1))
+
   p.basic  <- ggplot2::ggplot(df, aes(FPR, TPR, label = thr)) +
                 geom_roc(stat = "identity") +
                 style_roc()
@@ -163,7 +165,7 @@ sMSROC_plot <- function(sMS, m.value){
                                    breaks = seq(0,1,0.2)) +
                 scale_y_continuous(limits = c(0,1),
                                    breaks = seq(0,1,0.2)) +
-                geom_line(data = df1, aes(x, y), size = 1.5, colour = "gray", linetype = "twodash")
+                geom_line(data = df1, aes(x, y), linewidth = 1.5, colour = "gray", linetype = "twodash")
   ret <- list()
   ret$basicplot <- p.basic
   ret$rocplot   <- roc.plot
